/*===================================================================
 File name:	    T_6680_trans1_temp_0A8A.inc
 Date:      	  Aug. 21. 2006
---------------------------------------------------------------------
 DESCRIPTION:
 Transducer Block 1: Temperature
                                      
 DEVICE:
 T6680 Humidity Device 
---------------------------------------------------------------------
 Revision history:
 REV 0.01 DATE:210806	 TMG/WZ first release

===================================================================*/


/**************************************************/
/******************* Configuration ****************/
/**************************************************/


#ifndef SIPAST_MACROS_300_INC_INCLUDED
#include "SIPAST_Macros_300.inc"
#endif



#ifndef TRANS1_TITLE
#define TRANS1_TITLE	[Temperatur_Transducer]
#endif

#define _TRANS1_TEMP
#include "T_6680_trans1_0A8A.inc"

#define NO_trans1_secondary_value_2 // Disables the optional parameter trans1_secondary_value_2.
#define NO_trans1_max_sensor_value_1 // Disables the optional parameter trans1_max_sensor_value_1.
#define NO_trans1_max_sensor_value_2 // Disables the optional parameter trans1_max_sensor_value_2.
#define NO_trans1_min_sensor_value_1 // Disables the optional parameter trans1_min_sensor_value_1.
#define NO_trans1_min_sensor_value_2 // Disables the optional parameter trans1_min_sensor_value_2.
#define NO_trans1_minmax_sensor_value // Disables the optional parameter trans1_minmax_sensor_value.
#define NO_trans1_sensor_wire_check_1 // Disables the optional parameter trans1_sensor_wire_check_1.
#define NO_trans1_sensor_wire_check_2 // Disables the optional parameter trans1_sensor_wire_check_2.
#define NO_trans1_input_fault_2 // Disables the optional parameter trans1_input_fault_2.
#define NO_trans1_bias_2 // Disables the optional parameter trans1_bias_2.


/**************************************************/
/******************* Macros ***********************/
/**************************************************/


#define TRANS1_LOAD_TO_PC								\
		trans1_st_rev,								\
		trans1_primary_value_unit,					\
		trans1_lower_sensor_limit,					\
		trans1_upper_sensor_limit,					\
		trans1_input_range

#define TRANS1_LOAD_TO_DEVICE							\
		trans1_primary_value_unit,					\
		trans1_input_range



/**************************************************/
/*************** Windows and dialogs **************/
/**************************************************/

MENU Page_display_trans1
{
	LABEL		[menu_dialog_display_measure];
	ITEMS
	{
		trans1_primary_value_unit		(HIDDEN),
		BarVal_pv_display_trans1,
		Group_display_primary_trans1,
		Group_display_secondary_trans1
	}
}

MENU BarVal_pv_display_trans1
{
	LABEL		[trans_value];
	ITEMS
	{
		trans1_primary_value,
		func1_AI_pv_lower_range_value (READ_ONLY),
		func1_AI_pv_upper_range_value (READ_ONLY)
	}
}

MENU Group_display_primary_trans1
{
	LABEL		[trans_value];
	ITEMS
	{
		trans1_primary_value,
		SEPARATOR,
		trans1_primary_value_status_quality,
		trans1_primary_value_status_limit
	}
}

MENU Group_display_secondary_trans1
{
	ITEMS
	{
		trans1_secondary_value_1,
#ifndef NO_trans1_secondary_value_2
		trans1_secondary_value_2,
#endif
		trans1_reference_junction_temp,
		SEPARATOR,
		trans1_input_fault_gen,
		trans1_input_fault_1,
		trans1_input_fault_2
	}
}


#ifndef NO_trans1_minmax_sensor_value

#define TRANS1_MEASINDICATOR_AVAILABLE

MENU group_trans1_measindicator
{
	LABEL		TRANS1_TITLE ;
	ITEMS
	{
#ifndef NO_trans1_min_sensor_value_1
		trans1_min_sensor_value_1 (READ_ONLY),
#endif

#ifndef NO_trans1_max_sensor_value_1
		trans1_max_sensor_value_1 (READ_ONLY),
#endif

#ifndef NO_trans1_min_sensor_value_2
		trans1_min_sensor_value_2 (READ_ONLY),
#endif

#ifndef NO_trans1_max_sensor_value_2
		trans1_max_sensor_value_2 (READ_ONLY)
#endif
	}
}

#endif



// --- Parameter table --------------------------------------------------------

MENU Tab_s_trans1
{
	LABEL		TRANS1_TITLE ;
	ITEMS
	{
		trans1_primary_value_unit (READ_ONLY), 
		Tab_s_trans1_measrange
	}
}

MENU Tab_m_trans1
{
	LABEL		[trans_blk_parent_class_TEMP];
	ITEMS
	{
		trans1_primary_value_unit		(READ_ONLY),
		Tab_s_trans1_measrange
	}
}

MENU Tab_s_trans1_measrange
{
	LABEL		[menu_input_measrange];
	ITEMS
	{
		trans1_lower_sensor_limit,
		trans1_upper_sensor_limit
	}
}


// --- Parameter --------------------------------------------------------------

#define TRANS1_VALID_CHECK1						\
		SELECT (trans1_sensor_measure_type) \
			{								\
			CASE 0:							\
				TRUE;						\
			CASE 1:							\
				FALSE;						\
			CASE 128:						\
				TRUE;						\
			CASE 129:						\
				TRUE;						\
			CASE 192:						\
				TRUE;						\
			CASE 193:						\
				TRUE;						\
			DEFAULT:						\
				FALSE;						\
			}



#define TRANS1_VALID_CHECK2						\
		SELECT (trans1_sensor_measure_type) \
			{								\
			CASE 0:							\
				FALSE;						\
			CASE 1:							\
				TRUE;						\
			CASE 128:						\
				TRUE;						\
			CASE 129:						\
				TRUE;						\
			CASE 192:						\
				TRUE;						\
			CASE 193:						\
				TRUE;						\
			DEFAULT:						\
				FALSE;						\
			}




#define TRANS1_VALID_TC							\
	IF (trans1_lin_type >= 128)				\
	{										\
		IF (trans1_lin_type <= 144)			\
		{									\
			TRUE;							\
		}									\
		ELSE								\
		{									\
			FALSE;							\
		}									\
	}										\
	ELSE									\
	{										\
		FALSE;								\
	}

#define TRANS1_VALID_RTD							\
	IF (trans1_lin_type >= 100)				\
	{										\
		IF (trans1_lin_type <= 127)			\
		{									\
			TRUE;							\
		}									\
		ELSE								\
		{									\
			FALSE;							\
		}									\
	}										\
	ELSE									\
	{										\
		FALSE;								\
	}


#define TRANS1_VALID_NOT_TC						\
	IF( trans1_lin_type >= 128 )			\
	{	/* TC */							\
		FALSE ;								\
	}										\
	ELSE									\
	{										\
		TRUE ;								\
	}										\

#define TRANS1_VALID_NOT_TC1						\
	IF( trans1_lin_type >= 128 )			\
	{	/* TC */							\
		FALSE ;								\
	}										\
	ELSE									\
	{										\
		SELECT (trans1_sensor_measure_type) \
			{								\
			CASE 0:							\
				IF ( trans1_sensor_connection == 0 ) \
				{							\
					TRUE;					\
				}							\
				ELSE						\
				{							\
					FALSE;					\
				}							\
			CASE 1:							\
				FALSE;						\
			CASE 128:						\
				TRUE;						\
			CASE 129:						\
				TRUE;						\
			CASE 192:						\
				TRUE;						\
			CASE 193:						\
				TRUE;						\
			DEFAULT:						\
				FALSE;						\
			}								\
	}

#define TRANS1_VALID_NOT_TC2						\
	IF( trans1_lin_type >= 128 )			\
	{	/* TC */							\
		FALSE ;								\
	}										\
	ELSE									\
	{										\
		SELECT (trans1_sensor_measure_type) \
			{								\
			CASE 0:							\
				FALSE;						\
			CASE 1:							\
				IF ( trans1_sensor_connection == 0 ) \
				{							\
					TRUE;					\
				}							\
				ELSE						\
				{							\
					FALSE;					\
				}							\
			CASE 128:						\
				TRUE;						\
			CASE 129:						\
				TRUE;						\
			CASE 192:						\
				TRUE;						\
			CASE 193:						\
				TRUE;						\
			DEFAULT:						\
				FALSE;						\
			}								\
	}


VARIABLE trans1_lin_type
{
	LABEL		[trans_lin_type];
	HELP		[trans_lin_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		{ 0,	[linear]		},
		{ 100,	[RTD_Pt10]		},
		{ 101,	[RTD_Pt50]		},
		{ 102,	[RTD_Pt100]		},
		{ 103,	[RTD_Pt200]		},
		{ 104,	[RTD_Pt500]		},
		{ 105,	[RTD_Pt1000]		},

		{ 106,	[RTD_Pt10_JIS]		},
		{ 107,	[RTD_Pt50_JIS]		},
		{ 108,	[RTD_Pt100_JIS]	},
		{ 109,	[RTD_Pt10_MIL]		},
		{ 110,	[RTD_Pt50_MIL]		},
		{ 111,	[RTD_Pt100_MIL]	},
		{ 112,	[RTD_Pt200_MIL]	},
		{ 113,	[RTD_Pt500_MIL]	},
		{ 114,	[RTD_Pt1000_MIL]	},
		{ 115,	[RTD_Pt100_SAM]	},
		{ 116,	[RTD_Pt200_SAM]	},
		{ 117,	[RTD_Pt100_IPT]	},
		{ 118,	[RTD_Ni50_Edi]		},
		{ 119,	[RTD_Ni100_Edi]	},
		{ 120,	[RTD_Ni120_Edi]	},
		{ 121,	[RTD_Ni1000_Edi]	},

		{ 122,	[RTD_Ni50]		},

		{ 123,	[RTD_Ni100]		},
		{ 124,	[RTD_Ni120]		},
		{ 125,	[RTD_Ni1000]		},
		{ 126,	[RTD_Cu10]		},
		{ 127,	[RTD_Cu100]		},


		{ 128,	[TC_type_B]		},
		{ 129,	[TC_type_C]		},
		{ 130,	[TC_type_D]		},
		{ 131,	[TC_type_E]		},
		{ 132,	[TC_type_G]		},
		{ 133,	[TC_type_J]		},
		{ 134,	[TC_type_K]		},
		{ 135,	[TC_type_N]		},
		{ 136,	[TC_type_R]		},
		{ 137,	[TC_type_S]		},
		{ 138,	[TC_type_T]		},
		{ 139,	[TC_type_L]		},
		{ 140,	[TC_type_U]		},

		{ 141,	[TC_type_Pt20]		},
		{ 142,	[TC_type_Ir40]		},
		{ 143,	[TC_type_Plat]		},
		{ 144,	[TC_type_Ni]		}

	}
	HANDLING	READ & WRITE;

	POST_EDIT_ACTIONS
	{
		method_set_trans1_primary_value_unit,
		method_set_trans1_input_range
	}

}

VARIABLE trans1_primary_value
{
	LABEL		[trans_value];
	HELP		[trans_temp_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DISPLAY_FORMAT	"7.3f";
	}
	HANDLING	READ;
}

VARIABLE trans1_primary_value_status_quality
{
	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

trans1_primary_value_status_limit			LIKE VARIABLE	trans1_primary_value_status_quality
{
	REDEFINE LABEL		[status_limit];
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_OUTPUT_LIMIT
	}
}

VARIABLE trans1_primary_value_unit
{
	LABEL		[digital_units];
	HELP		[digital_units_help];	/* ??? Text */
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE 1001;
			/* K	*/	{ 1000,	[unit_1000],	[unit_1000_help]	},
			/* degC	*/	{ 1001,	[unit_1001],	[unit_1001_help]	},
			/* degF	*/	{ 1002,	[unit_1002],	[unit_1002_help]	},
			/* Rk	*/	{ 1003,	[unit_1003],	[unit_1003_help]	}
	}
	POST_EDIT_ACTIONS
	{
		method_set_trans1_input_range
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_secondary_value_1
{
	LABEL		[trans_temp_temperature_1];
	HELP		[trans_temp_temperature_1_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DISPLAY_FORMAT	"7.3f";
	}
	HANDLING	READ;
}

VARIABLE trans1_secondary_value_1_status_quality
{
	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

trans1_secondary_value_1_status_limit		LIKE VARIABLE	trans1_secondary_value_1_status_quality
{
	REDEFINE LABEL		[status_limit];
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_OUTPUT_LIMIT
	}
}

#ifndef NO_trans1_secondary_value_2
	VARIABLE trans1_secondary_value_2
{
	LABEL		[trans_temp_temperature_2];
	HELP		[trans_temp_temperature_2_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT
	{
		DISPLAY_FORMAT	"7.3f";
	}
	HANDLING	READ;
}

#endif

VARIABLE trans1_secondary_value_2_status_quality
{
	LABEL		[status_quality];
	HELP		[value_status_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0;
		STATUS_OUTPUT_NO_RCAS
	}
	HANDLING	READ;
}

trans1_secondary_value_2_status_limit		LIKE VARIABLE	trans1_secondary_value_2_status_quality
{
	REDEFINE LABEL		[status_limit];
	REDEFINE TYPE		ENUMERATED (1)
	{
		STATUS_OUTPUT_LIMIT
	}
}

VARIABLE trans1_sensor_measure_type
{
	LABEL		[trans_temp_sensor_measure_type];
	HELP		[trans_temp_sensor_measure_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 0 ;

		{	0,	[trans_temp_sensor_measure_type_T1]			},
		{	1,	[trans_temp_sensor_measure_type_T2]			},
		{	128,	[trans_temp_sensor_measure_type_T1_SUB_T2]		},
		{	129,	[trans_temp_sensor_measure_type_T2_SUB_T1]		},
		{	192,	[trans_temp_sensor_measure_type_AVE]		},
		{	193,	[trans_temp_sensor_measure_type_AVE_T1_OR_T2]	}
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_input_range
{
	LABEL		[trans_temp_input_range];
	HELP		[trans_temp_input_range_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
	  250
	}
	HANDLING	READ & WRITE;
}

VARIABLE trans1_bias_1
{
	LABEL		[trans_temp_bias_1];
	HELP		[trans_temp_bias_1_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		DISPLAY_FORMAT	"7.3f";
	}
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_CHECK1
}

#ifndef NO_trans1_bias_2
VARIABLE trans1_bias_2
{
	LABEL		[trans_temp_bias_2];
	HELP		[trans_temp_bias_2_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		DISPLAY_FORMAT	"7.3f";
	}
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_CHECK2
}
#endif

VARIABLE trans1_upper_sensor_limit
{
	LABEL		[trans_sensor_upper_limit];
	HELP		[trans_sensor_upper_limit_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 100 ;
	}
	HANDLING	READ;
}

VARIABLE trans1_lower_sensor_limit
{
	LABEL		[trans_sensor_lower_limit];
	HELP		[trans_sensor_lower_limit_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE 0 ;
	}
	HANDLING	READ;
}

#ifndef NO_trans1_max_sensor_value_1
VARIABLE trans1_max_sensor_value_1
{
	LABEL		[trans_max_sensor_value_1];
	HELP		[trans_max_sensor_value_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_CHECK1

}
#endif

#ifndef NO_trans1_max_sensor_value_2
VARIABLE trans1_max_sensor_value_2
{
	LABEL		[trans_max_sensor_value_2];
	HELP		[trans_max_sensor_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_CHECK2

}
#endif

#ifndef NO_trans1_min_sensor_value_1
VARIABLE trans1_min_sensor_value_1
{
	LABEL		[trans_min_sensor_value_1];
	HELP		[trans_min_sensor_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_CHECK1

}
#endif

#ifndef NO_trans1_min_sensor_value_1
VARIABLE trans1_min_sensor_value_2
{
	LABEL		[trans_min_sensor_value_2];
	HELP		[trans_min_sensor_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT;
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_CHECK2

}
#endif

VARIABLE trans1_input_fault_gen
{
	LABEL		[trans_temp_input_fault];
	HELP		[trans_temp_input_fault_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (1)
	{
		{ 0x00,	[trans_temp_input_fault_OK]			},
		{ 0x01,	[trans_temp_input_fault_RJ_ERR]		},
		{ 0x02,	[trans_temp_input_fault_HW_ERR]		}
	}
	HANDLING	READ;
}

VARIABLE trans1_input_fault_1
{
	LABEL		[trans_temp_input_fault_CH1_FAULT];
	HELP		[trans_temp_input_fault_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (1)
	{
		{ 0x00,	[trans_temp_input_fault_OK]			},
		{ 0x01,	[trans_temp_input_fault_UNDERRANGE]		},
		{ 0x02,	[trans_temp_input_fault_OVERRANGE]		},
		{ 0x04,	[trans_temp_input_fault_LEAD_BREAK]		},
		{ 0x08,	[trans_temp_input_fault_SHORT_CIRCUIT]	},
	}
	HANDLING	READ;
}

#ifndef NO_trans1_input_fault_2
VARIABLE trans1_input_fault_2
{
	LABEL		[trans_temp_input_fault_CH2_FAULT];
	HELP		[trans_temp_input_fault_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (1)
	{
		{ 0x00,	[trans_temp_input_fault_OK]				},
		{ 0x01,	[trans_temp_input_fault_UNDERRANGE]		},
		{ 0x02,	[trans_temp_input_fault_OVERRANGE]		},
		{ 0x04,	[trans_temp_input_fault_LEAD_BREAK]		},
		{ 0x08,	[trans_temp_input_fault_SHORT_CIRCUIT]	},
	}
	HANDLING	READ;
}

#endif

#ifndef NO_trans1_sensor_wire_check_1
	VARIABLE trans1_sensor_wire_check_1
{
	LABEL		[trans_sensor_wire_check_1];
	HELP		[trans_sensor_wire_check_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 3;

		{	0,	[trans_sensor_wire_check_BREAK_ON_SHORT_ON]	},
		{	1,	[trans_sensor_wire_check_BREAK_ON_SHORT_OFF]	},
		{	2,	[trans_sensor_wire_check_BREAK_OFF_SHORT_ON]	},
		{	3,	[disabled]						}
	}
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_CHECK1

}
#endif

#ifndef NO_trans1_sensor_wire_check_2
VARIABLE trans1_sensor_wire_check_2
{
	LABEL		[trans_sensor_wire_check_2];
	HELP		[trans_sensor_wire_check_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 3;

		{	0,	[trans_sensor_wire_check_BREAK_ON_SHORT_ON]		},
		{	1,	[trans_sensor_wire_check_BREAK_ON_SHORT_OFF]	},
		{	2,	[trans_sensor_wire_check_BREAK_OFF_SHORT_ON]	},
		{	3,	[disabled]										}
	}
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_CHECK2

}
#endif

/*-------------------------------------------------------------------------------------------------*/
/*    Transducer Block: Thermocouple Temperature Device (TC)	   */
/*-------------------------------------------------------------------------------------------------*/

VARIABLE trans1_reference_junction_temp
{
	LABEL		[trans_temp_rj_temp];
	HELP		[trans_temp_rj_temp_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		FLOAT;
	HANDLING	READ;
	VALIDITY	TRANS1_VALID_TC
}

VARIABLE trans1_reference_junction_type
{
	LABEL		[trans_temp_rj_type];
	HELP		[trans_temp_rj_type_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE 1;
		{ 0,	[trans_temp_rj_type_NONE] },
		{ 1,	[trans_temp_rj_type_INT] },
		{ 2,	[trans_temp_rj_type_EXT] }
	}
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_TC
}

VARIABLE trans1_external_reference_junction_value
{
	LABEL		[trans_temp_external_rj_value];
	HELP		[trans_temp_external_rj_value_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		DISPLAY_FORMAT	"7.3f";
	}
	HANDLING	READ & WRITE;
	VALIDITY	IF( trans1_reference_junction_type == 2 )
				{
					TRUE ;
				}
				ELSE
				{
					FALSE ;
				}
}

/*-------------------------------------------------------------------------------------------------------------*/
/*    Transducer Block: Thermoresistance Temperature Device (RTD)	   */
/*-------------------------------------------------------------------------------------------------------------*/

VARIABLE trans1_sensor_connection
{
	LABEL		[trans_temp_sensor_connection];
	HELP		[trans_temp_sensor_connection_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	2;
    {
    	2,	[trans_temp_sensor_connection_4_WIRE]		
    }
	}
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_NOT_TC
}

VARIABLE trans1_comp_wire_1
{
	LABEL		[trans_temp_comp_wire1];
	HELP		[trans_temp_comp_wire1_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		DISPLAY_FORMAT	"7.3f";
	}
	CONSTANT_UNIT	[Ohm];
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_NOT_TC1
}

VARIABLE trans1_comp_wire_2
{
	LABEL		[trans_temp_comp_wire2];
	HELP		[trans_temp_comp_wire2_help];
	CLASS		CONTAINED;
	TYPE		FLOAT
	{
		DEFAULT_VALUE	0.0;
		DISPLAY_FORMAT	"7.3f";
	}
	CONSTANT_UNIT	[Ohm];
	HANDLING	READ & WRITE;
	VALIDITY	TRANS1_VALID_NOT_TC2
}

/**************************************************
************* TB_Temp Block Commands **************
**************************************************/



COMMAND read_trans1_primary_value
{
	BLOCK transducer_block_1;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_primary_value,
			trans1_primary_value_status_quality	<0xFC>,
			trans1_primary_value_status_limit	<0x03>
		}
	}
}

COMMAND read_trans1_primary_value_unit
{
	BLOCK transducer_block_1;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_primary_value_unit
		}
	}
}

COMMAND write_trans1_primary_value_unit
{
	BLOCK transducer_block_1;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_primary_value_unit
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_secondary_value_1
{
	BLOCK transducer_block_1;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_secondary_value_1,
			trans1_secondary_value_1_status_quality	<0xFC>,
			trans1_secondary_value_1_status_limit	<0x03>
		}
	}
}


#ifndef NO_trans1_secondary_value_2
COMMAND read_trans1_secondary_value_2
{
	BLOCK transducer_block_1;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_secondary_value_2,
			trans1_secondary_value_2_status_quality	<0xFC>,
			trans1_secondary_value_2_status_limit	<0x03>
		}
	}
}

#endif

COMMAND read_trans1_sensor_measure_type
{
	BLOCK transducer_block_1;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_sensor_measure_type
		}
	}
}

COMMAND write_trans1_sensor_measure_type
{
	BLOCK transducer_block_1;
	INDEX 12;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_sensor_measure_type
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_input_range
{
	BLOCK transducer_block_1;
	INDEX 13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_input_range
		}
	}
}

COMMAND write_trans1_input_range
{
	BLOCK transducer_block_1;
	INDEX 13;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_input_range
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_lin_type
{
	BLOCK transducer_block_1;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_lin_type
		}
	}
}

COMMAND write_trans1_lin_type
{
	BLOCK transducer_block_1;
	INDEX 14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_lin_type
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_bias_1
{
	BLOCK transducer_block_1;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_bias_1
		}
	}
}

COMMAND write_trans1_bias_1
{
	BLOCK transducer_block_1;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_bias_1
		}
		REPLY
		{
		}
	}
}

#ifndef NO_trans1_bias_2
	COMMAND read_trans1_bias_2
{
	BLOCK transducer_block_1;
	INDEX 20;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 trans1_bias_2
		}
	}
}

#endif

#ifndef NO_trans1_bias_2
	COMMAND write_trans1_bias_2
{
	BLOCK transducer_block_1;
	INDEX 20;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_bias_2
		}
		REPLY
		{
		}
	}
}

#endif

COMMAND read_trans1_upper_sensor_limit
{
	BLOCK transducer_block_1;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_upper_sensor_limit
		}
	}
}

COMMAND read_trans1_lower_sensor_limit
{
	BLOCK transducer_block_1;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_lower_sensor_limit
		}
	}
}

COMMAND read_trans1_input_fault_gen
{
	BLOCK transducer_block_1;
	INDEX 24;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_input_fault_gen
		}
	}
}

COMMAND read_trans1_input_fault_1
{
	BLOCK transducer_block_1;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_input_fault_1
		}
	}
}

#ifndef NO_trans1_input_fault_2
	COMMAND read_trans1_input_fault_2
{
	BLOCK transducer_block_1;
	INDEX 26;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_input_fault_2
		}
	}
}
#endif

#ifndef NO_trans1_sensor_wire_check_1
	COMMAND read_trans1_sensor_wire_check_1
{
	BLOCK transducer_block_1;
	INDEX 27;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_sensor_wire_check_1
		}
	}
}

COMMAND write_trans1_sensor_wire_check_1
{
	BLOCK transducer_block_1;
	INDEX 27;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_sensor_wire_check_1
		}
		REPLY
		{
		}
	}
}
#endif

#ifndef NO_trans1_sensor_wire_check_2
COMMAND read_trans1_sensor_wire_check_2
{
	BLOCK transducer_block_1;
	INDEX 28;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_sensor_wire_check_2
		}
	}
}

COMMAND write_trans1_sensor_wire_check_2
{
	BLOCK transducer_block_1;
	INDEX 28;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_sensor_wire_check_2
		}
		REPLY
		{
		}
	}
}
#endif

#ifndef NO_trans1_max_sensor_value_1
	COMMAND read_trans1_max_sensor_value_1
{
	BLOCK transducer_block_1;
	INDEX 29;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_max_sensor_value_1
		}
	}
}

COMMAND write_trans1_max_sensor_value_1
{
	BLOCK transducer_block_1;
	INDEX 29;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_max_sensor_value_1
		}
		REPLY
		{
		}
	}
}
#endif

#ifndef NO_trans1_min_sensor_value_1
COMMAND read_trans1_min_sensor_value_1
{
	BLOCK transducer_block_1;
	INDEX 30;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_min_sensor_value_1
		}
	}
}

COMMAND write_trans1_min_sensor_value_1
{
	BLOCK transducer_block_1;
	INDEX 30;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_min_sensor_value_1
		}
		REPLY
		{
		}
	}
}
#endif

#ifndef NO_trans1_max_sensor_value_2
	COMMAND read_trans1_max_sensor_value_2
{
	BLOCK transducer_block_1;
	INDEX 31;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_max_sensor_value_2
		}
	}
}

COMMAND write_trans1_max_sensor_value_2
{
	BLOCK transducer_block_1;
	INDEX 31;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_max_sensor_value_2
		}
		REPLY
		{
		}
	}
}
#endif

#ifndef NO_trans1_min_sensor_value_2
COMMAND read_trans1_min_sensor_value_2
{
	BLOCK transducer_block_1;
	INDEX 32;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_min_sensor_value_2
		}
	}
}

COMMAND write_trans1_min_sensor_value_2
{
	BLOCK transducer_block_1;
	INDEX 32;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_min_sensor_value_2
		}
		REPLY
		{
		}
	}
}
#endif

COMMAND read_trans1_reference_junction_temp
{
	BLOCK transducer_block_1;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_reference_junction_temp
		}
	}
}

COMMAND read_trans1_reference_junction_type
{
	BLOCK transducer_block_1;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_reference_junction_type
		}
	}
}

COMMAND write_trans1_reference_junction_type
{
	BLOCK transducer_block_1;
	INDEX 34;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_reference_junction_type
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_external_reference_junction_value
{
	BLOCK transducer_block_1;
	INDEX 35;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_external_reference_junction_value
		}
	}
}

COMMAND write_trans1_external_reference_junction_value
{
	BLOCK transducer_block_1;
	INDEX 35;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_external_reference_junction_value
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_sensor_connection
{
	BLOCK transducer_block_1;
	INDEX 36;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_sensor_connection
		}
	}
}

COMMAND write_trans1_sensor_connection
{
	BLOCK transducer_block_1;
	INDEX 36;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_sensor_connection
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_comp_wire_1
{
	BLOCK transducer_block_1;
	INDEX 37;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_comp_wire_1
		}
	}
}

COMMAND write_trans1_comp_wire_1
{
	BLOCK transducer_block_1;
	INDEX 37;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_comp_wire_1
		}
		REPLY
		{
		}
	}
}

COMMAND read_trans1_comp_wire_2
{
	BLOCK transducer_block_1;
	INDEX 38;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans1_comp_wire_2
		}
	}
}

COMMAND write_trans1_comp_wire_2
{
	BLOCK transducer_block_1;
	INDEX 38;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans1_comp_wire_2
		}
		REPLY
		{
		}
	}
}


/*******************************************************************************/
/*****	Methods		************************************************************/
/*******************************************************************************/

// --- Unit relations ---------------------------------------------------------

/* Temperature Transducer Block */
UNIT TB_TEMPERATURE_UNIT_TRANS1
{
	trans1_primary_value_unit:

	trans1_primary_value,
	trans1_secondary_value_1,

#ifndef NO_trans1_secondary_value_2
	trans1_secondary_value_2,
#endif

	trans1_upper_sensor_limit,
	trans1_lower_sensor_limit,
	trans1_reference_junction_temp,
	trans1_external_reference_junction_value,

#ifndef NO_trans1_min_sensor_value_1
	trans1_min_sensor_value_1,
#endif

#ifndef NO_trans1_max_sensor_value_1
	trans1_max_sensor_value_1
#endif

}

