/*===================================================================
 File name:	    T_6680_trans2_0A8A.inc
 Date:      	  Aug. 21. 2006
---------------------------------------------------------------------
 DESCRIPTION:
 Transducer Block 2: Common parameters
                                      
 DEVICE:
 T6680 Humidity Device 
---------------------------------------------------------------------
 Revision history:
 REV 0.01 DATE:210806	 TMG/WZ first release

===================================================================*/


#define TRANS2_AVAILABLE




/**************************************************/
/******************* Configuration ****************/
/**************************************************/

// PROFILE_REV:		0x200 or 0x300

#ifndef TRANS2_TITLE
#define TRANS2_TITLE	[trans2]
#endif


#ifdef _TRANS2_FLOW_ELECTRO_MAG
#define _TRANS2_FLOW
#define _TRANS2_FLOW_VOLUME
#define DEFAULT_VALUE_trans2_blk_class				1
#endif

#ifdef _TRANS2_FLOW_VORTEX
#define _TRANS2_FLOW
#define _TRANS2_FLOW_VOLUME
#define DEFAULT_VALUE_trans2_blk_class				2
#endif

#ifdef _TRANS2_FLOW_CORIOLIS
#define _TRANS2_FLOW
#define _TRANS2_FLOW_MASS
#define DEFAULT_VALUE_trans2_blk_class				3
#endif

#ifdef _TRANS2_FLOW_THERMAL
#define _TRANS2_FLOW
#define _TRANS2_FLOW_MASS
#define DEFAULT_VALUE_trans2_blk_class				4
#endif

#ifdef _TRANS2_FLOW_ULTRASONIC
#define _TRANS2_FLOW
#define _TRANS2_FLOW_VOLUME
#define DEFAULT_VALUE_trans2_blk_class				5
#endif

#ifdef _TRANS2_LEVEL_HYDRO
#define _TRANS2_LEVEL
#define DEFAULT_VALUE_trans2_blk_class				1
#endif

#ifdef _TRANS2_LEVEL_ECHO
#define _TRANS2_LEVEL
#define DEFAULT_VALUE_trans2_blk_class				2
#endif

#ifdef _TRANS2_LEVEL_CAPACITIVE
#define _TRANS2_LEVEL
#define DEFAULT_VALUE_trans2_blk_class				4
#endif


#ifdef _TRANS2_PRESS
#define DEFAULT_VALUE_trans2_blk_parent_class		1
#endif

#ifdef _TRANS2_TEMP
#define DEFAULT_VALUE_trans2_blk_parent_class		2
#endif

#ifdef _TRANS2_FLOW
#define DEFAULT_VALUE_trans2_blk_parent_class		3
#endif

#ifdef _TRANS2_LEVEL
#define DEFAULT_VALUE_trans2_blk_parent_class		4
#endif

#ifdef _TRANS2_ANALYSIS
#define DEFAULT_VALUE_trans2_blk_parent_class		7
#define DEFAULT_VALUE_trans2_blk_class			1
#endif


#ifdef _TRANS2_DI
#define DEFAULT_VALUE_trans2_blk_parent_class		6
#endif


#ifndef DEFAULT_VALUE_trans2_blk_parent_class
#define DEFAULT_VALUE_trans2_blk_parent_class		252
#endif

#ifndef DEFAULT_VALUE_trans2_blk_class
#define DEFAULT_VALUE_trans2_blk_class				252
#endif


/**************************************************/
/******************* Macros ***********************/
/**************************************************/

#ifndef FLOAT_MIN
#define	FLOAT_MIN	-3.4E+38
#define	FLOAT_MAX	 3.4E+38
#endif


/**************************************************/
/*************** Windows and dialogs **************/
/**************************************************/

COLLECTION OF VARIABLE trans2
{
	MEMBERS
	{
		actual_mode,		trans2_actual_mode,			TRANS2_TITLE ;
	}
}



MENU Page_diagnosis_trans2
{
	LABEL		TRANS2_TITLE;
	ITEMS
	{
		trans2_blk_object,
		trans2_blk_parent_class,
		trans2_blk_class,
		trans2_blk_dd_reference,
		trans2_blk_dd_rev,
		trans2_blk_profile,
		trans2_blk_profile_rev,
		trans2_st_rev,
		trans2_actual_mode
	}
}


// --- Transducer Block Parameter -------------------------------------

BLOCK transducer_block_2
{
	TYPE	TRANSDUCER;
	NUMBER	2 ;
}



// -- Index 0: blk_object

COMMAND read_trans2_blk
{
	BLOCK transducer_block_2;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_blk_reserve, trans2_blk_object, trans2_blk_parent_class, trans2_blk_class,
			trans2_blk_dd_reference, trans2_blk_dd_rev, trans2_blk_profile, trans2_blk_profile_rev,
			trans2_blk_execution_time, trans2_blk_highest_rel_offset, trans2_blk_index_view_1,
			trans2_blk_num_view_lists
		}
	}
}

VARIABLE trans2_blk_reserve
{
	LABEL		[blk_reserved];
	HELP		[blk_reserved_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(1);
	HANDLING	READ;
}

VARIABLE trans2_blk_object
{
	LABEL		[blk_block_object];
	HELP		[blk_block_object_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		{	3,	[blk_block_object_TRANSDUCER]		}
	}
	HANDLING	READ;
}

VARIABLE trans2_blk_parent_class
{
	LABEL		[blk_parent_class];
	HELP		[trans_blk_parent_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	DEFAULT_VALUE_trans2_blk_parent_class ;
		{	1,	[trans_blk_parent_class_PRES]	},
		{	2,	[trans_blk_parent_class_TEMP]	},
		{	3,	[trans_blk_parent_class_FLOW]	},
		{	4,	[trans_blk_parent_class_LEVEL]	},
		{	6,	[trans_blk_parent_class_BIN_IO]	},
		{	7,	[trans_blk_parent_class_ANALYSIS]	},
		{	252,	[unknown]					}
	}
	HANDLING	READ;
}

VARIABLE trans2_blk_class
{
	LABEL		[blk_class];
	HELP		[trans_blk_class_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED(1)
	{
		DEFAULT_VALUE	DEFAULT_VALUE_trans2_blk_class ;

		SELECT( trans2_blk_parent_class )
		{
			CASE 1:
			{	1,		[trans_pres_blk_class_DIFF]	},
			{	2,		[trans_pres_blk_class_ABS]	},
			{	3,		[trans_pres_blk_class_GAGE]	},

			CASE 2:
			{	1,		[trans_temp_blk_class_TC]	},
			{	2,		[trans_temp_blk_class_RTD]	},
			{	3,		[trans_temp_blk_class_PYR]	},
			{	16,		"TC + DC U"					},
			{	17,		"RTD + R"					},
			{	18,		"TC + RTD + R + DC U"		},

			CASE 3:
			{	1,		[trans_flow_blk_class_MAGNETIC]	},
			{	2,		[trans_flow_blk_class_VORTEX]	},
			{	3,		[trans_flow_blk_class_CORIOLIS]	},
			{	4,		[trans_flow_blk_class_THERMAL]	},
			{	5,		[trans_flow_blk_class_ULTRASONIC]},

			CASE 4:
			{	1,		[trans_lev_blk_class_HYDRO]	},
			{	2,		[trans_lev_blk_class_ECHO]	},
			{	4,		[trans_lev_blk_class_CAPACITIVE]},
			DEFAULT:
			{	1,		[standard]					},

		}

		{	250,	[not_used] 					},
		{	251,	[none]						},
		{	252,	[unknown]					},
		{	253,	[special]					}
	}
	HANDLING	READ;
}

VARIABLE trans2_blk_dd_reference
{
	LABEL		[blk_dd_reference];
	HELP		[blk_dd_reference_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (4);
	HANDLING	READ;
}

VARIABLE trans2_blk_dd_rev
{
	LABEL		[blk_dd_rev];
	HELP		[blk_dd_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER(2);
	HANDLING	READ;
}

VARIABLE trans2_blk_profile
{
	LABEL		[blk_profile];
	HELP		[blk_profile_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
		DEFAULT_VALUE	0x4002; 
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_blk_profile_rev
{
	LABEL		[blk_profile_rev];
	HELP		[blk_profile_rev_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (2)
	{
#ifdef PROFILE_REV
		DEFAULT_VALUE PROFILE_REV ;
#endif
		{	0x0200,	"2.0"	},
		{	0x025D,	"2.93"	},
		{	0x025F,	"2.95"	},
		{	0x0300,	"3.0"	},
		{ 0x0301, "3.01" }

	}
	HANDLING	READ;
}

VARIABLE trans2_blk_execution_time
{
	LABEL		[blk_execution_time];
	HELP		[blk_execution_time_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;

}

VARIABLE trans2_blk_highest_rel_offset
{	// Profile 3: number of parameters
	LABEL		[blk_highest_rel_offset];
	HELP		[blk_highest_rel_offset_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
	POST_READ_ACTIONS
	{
		DEFINITION
		{
			trans2_blk_num_parameters = trans2_blk_highest_rel_offset ;
		}
	}
}

VARIABLE trans2_blk_num_parameters
{
	LABEL		[blk_num_parameters];
	HELP		[blk_num_parameters_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}




VARIABLE trans2_blk_index_view_1
{
	LABEL		[blk_index_view_1];
	HELP		[blk_index_view_1_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ;
}

VARIABLE trans2_blk_num_view_lists
{
	LABEL		[blk_num_view_lists];
	HELP		[blk_num_view_lists_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ;
}



// -- Index 1: st_rev

COMMAND read_trans2_st_rev
{
	BLOCK transducer_block_2;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_st_rev
		}
	}
}

VARIABLE trans2_st_rev
{
	LABEL		[st_rev];
	HELP		[st_rev_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2)
	{
		DEFAULT_VALUE	0;
	}
	HANDLING	READ;
}



// -- Index 2: tag_desc

VARIABLE trans2_tag_desc
{
	LABEL		[tag_desc];
	HELP		[tag_desc_help];
	CLASS		CONTAINED;
	TYPE		ASCII (32);
	HANDLING	READ & WRITE;
}

COMMAND read_trans2_tag_desc
{
	BLOCK transducer_block_2;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_tag_desc
		}
	}
}

COMMAND write_trans2_tag_desc
{
	BLOCK transducer_block_2;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_tag_desc
		}
		REPLY
		{
		}
	}
}



// -- Index 3: strategy

COMMAND read_trans2_strategy
{
	BLOCK transducer_block_2;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_strategy
		}
	}
}

COMMAND write_trans2_strategy
{
	BLOCK transducer_block_2;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_strategy
		}
		REPLY
		{
		}
	}
}

VARIABLE trans2_strategy
{
	LABEL		[strategy];
	HELP		[strategy_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (2);
	HANDLING	READ & WRITE;
}



// -- Index 4: alert key

VARIABLE trans2_alert_key
{
	LABEL		[alert_key];
	HELP		[alert_key_help];
	CLASS		CONTAINED;
	TYPE		UNSIGNED_INTEGER (1);
	HANDLING	READ & WRITE;
}

COMMAND read_trans2_alert_key
{
	BLOCK transducer_block_2;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_alert_key
		}
	}
}

COMMAND write_trans2_alert_key
{
	BLOCK transducer_block_2;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_alert_key
		}
		REPLY
		{
		}
	}
}



// Index 5: target_mode

COMMAND read_trans2_target_mode
{
	BLOCK transducer_block_2;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_target_mode
		}
	}
}

COMMAND write_trans2_target_mode
{
	BLOCK transducer_block_2;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			trans2_target_mode
		}
		REPLY
		{
		}
	}
}

VARIABLE trans2_target_mode
{
	LABEL		[target_mode];
	HELP		[target_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	} //Difference to Siemens, in order to set the TB O/S

	}
	HANDLING	READ & WRITE;
}



// -- Index 6: mode

COMMAND read_trans2_mode
{
	BLOCK transducer_block_2;
	INDEX 6;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			 trans2_actual_mode, trans2_permitted_mode, trans2_normal_mode
		}
	}
}

VARIABLE trans2_actual_mode
{
	LABEL		[actual_mode];
	HELP		[actual_mode_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_permitted_mode
{
	LABEL		[permitted_mode];
	HELP		[permitted_mode_help];
	CLASS		CONTAINED;
	TYPE		BIT_ENUMERATED (1)
	{
		DEFAULT_VALUE	0x08;
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_normal_mode
{
	LABEL		[normal_mode];
	HELP		[normal_mode_help];
	CLASS		CONTAINED;
	TYPE		ENUMERATED (1)
	{
		{	0x08,	[mode_AUTO]				}
	}
	HANDLING	READ;
}


// -- Index 7

COMMAND read_trans2_alarm
{
	BLOCK transducer_block_2;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			trans2_current_state_alarm_sum, trans2_unacknowledged_state_alarm_sum,
			trans2_unreported_state_alarm_sum, trans2_disabled_state_alarm_sum
		}
	}
}

VARIABLE trans2_current_state_alarm_sum
{
	LABEL		[current_state_alarm_sum];
	HELP		[current_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_unacknowledged_state_alarm_sum
{
	LABEL		[unacknowledged_state_alarm_sum];
	HELP		[unacknowledged_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_unreported_state_alarm_sum
{
	LABEL		[unreported_state_alarm_sum];
	HELP		[unreported_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}

VARIABLE trans2_disabled_state_alarm_sum
{
	LABEL		[disabled_state_alarm_sum];
	HELP		[disabled_state_alarm_sum_help];
	CLASS		CONTAINED & DYNAMIC;
	TYPE		BIT_ENUMERATED (2)
	{
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
	HANDLING	READ;
}





